@@ -1,24 +1,31 @@
-/* idn-free.h --- Invoke the `free' function releasing memory
- *                allocated by libidn functions.
- * Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009 Simon Josefsson
- *
- * This file is part of GNU Libidn.
- *
- * GNU Libidn is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * GNU Libidn is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with GNU Libidn; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- */
+/* idn-free.h --- Invoke the free function to release memory
+   Copyright (C) 2004-2021 Simon Josefsson
+
+   This file is part of GNU Libidn.
+
+   GNU Libidn is free software: you can redistribute it and/or
+   modify it under the terms of either:
+
+     * the GNU Lesser General Public License as published by the Free
+       Software Foundation; either version 3 of the License, or (at
+       your option) any later version.
+
+   or
+
+     * the GNU General Public License as published by the Free
+       Software Foundation; either version 2 of the License, or (at
+       your option) any later version.
+
+   or both in parallel, as here.
+
+   GNU Libidn is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
+
+   You should have received copies of the GNU General Public License and
+   the GNU Lesser General Public License along with this program.  If
+   not, see <http://www.gnu.org/licenses/>. */
 
 #ifndef IDN_FREE_H
 # define IDN_FREE_H
@@ -35,6 +42,11 @@
 #  endif
 # endif
 
+# ifdef __cplusplus
+extern "C"
+{
+# endif
+
 /* I don't recommend using this interface in general.  Use `free'.
  *
  * I'm told Microsoft Windows may use one set of `malloc' and `free'
@@ -53,6 +65,10 @@
  * information.
  */
 
-extern void IDNAPI idn_free (void *ptr);
+  extern void IDNAPI idn_free (void *ptr);
 
-#endif /* IDN_FREE_H */
+# ifdef __cplusplus
+}
+# endif
+
+#endif				/* IDN_FREE_H */
